@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 #ifndef __GPK_DBUS_H
@@ -64,6 +64,8 @@ GType		 gpk_dbus_error_get_type		(void);
 GType		 gpk_dbus_get_type			(void);
 GpkDbus		*gpk_dbus_new				(void);
 
+guint		 gpk_dbus_get_idle_time			(GpkDbus	*dbus);
+
 /* org.freedesktop.PackageKit.Query */
 void		 gpk_dbus_is_installed			(GpkDbus	*dbus,
 							 const gchar	*package_name,
@@ -110,6 +112,11 @@ void		 gpk_dbus_install_gstreamer_resources	(GpkDbus 	*dbus,
 							 gchar		**codecs,
 							 const gchar	*interaction,
 							 DBusGMethodInvocation *context);
+void		 gpk_dbus_remove_package_by_file	(GpkDbus	*dbus,
+							 guint32	 xid,
+							 gchar		**files,
+							 const gchar	*interaction,
+							 DBusGMethodInvocation *context);
 
 G_END_DECLS
 
